local addonName, L = ...;

local function LeaveArenaButton_OnClick()
	LeaveBattlefield();
end

local function TeamFrame_OnShow(self)

	local gameMode = ArenaLiveCore:GetDBEntry(addonName, "GameMode");
	
	-- Fill Frames with Player data:
	local currentPlayer = 0;

	for guid, infoTable in pairs(self.players) do
		if ( currentPlayer <= 3 ) then
			currentPlayer = currentPlayer + 1;
			
			local frame = self["player"..currentPlayer];
		
			-- Prepare Data:
			local name = infoTable["name"];
			
			local class = infoTable["class"];
			local red, green, blue = RAID_CLASS_COLORS[class]["r"], RAID_CLASS_COLORS[class]["g"], RAID_CLASS_COLORS[class]["b"];
			local damage = BreakUpLargeNumbers(math.ceil(infoTable["damage"]));
			local highestDamage = math.ceil(infoTable["highestDamage"]);
			local highestDamageAbility = infoTable["highestDamageAbility"];
			local highestDamageText;
			if ( highestDamage > 0 ) then
				highestDamageText = string.format(L["STATISTIC_HIGHEST_DAMAGE_TEXT_FORMAT"], BreakUpLargeNumbers(highestDamage), highestDamageAbility);
			else
				highestDamageText = BreakUpLargeNumbers(highestDamage);
			end
			
			local healing = BreakUpLargeNumbers(math.ceil(infoTable["healing"] + infoTable["absorb"]));
			local kills = infoTable["kills"];
			local secondsCCd = math.ceil(infoTable["timeCCed"]);
			local minutesCCd = math.floor(secondsCCd / 60);
			secondsCCd = secondsCCd - ( 60 * minutesCCd );
			
			if ( string.len(secondsCCd) == 1 ) then
				secondsCCd = "0"..secondsCCd;
			end
			
			local timeCCd = string.format(L["STATISTIC_TIME_CCD_TEXT_FORMAT"], minutesCCd, tostring(secondsCCd));
			
			frame.name:SetText(name);
			frame.name:SetTextColor(red, green, blue, 1);
			frame.damage:SetText(damage);
			frame.highestDamage:SetText(highestDamageText);
			frame.healing:SetText(healing);
			frame.killingBlows:SetText(kills);
			frame.timeCCd:SetText(timeCCd);
			frame.icon:SetTexCoord(unpack(CLASS_ICON_TCOORDS[class]));
		end
	end

	-- Hide/Show Frames:
	for i = 1, 3 do
		local frame = self["player"..i];
		
		if ( i <= gameMode and i <= currentPlayer ) then
			frame:Show()
		else
			frame:Hide();
		end
		
	
	end
	
end

function ALSpec_MatchStatistic:Initialise()
	ALSpec_MatchStatistic:InitialiseTeamFrames("Left");
	ALSpec_MatchStatistic:InitialiseTeamFrames("Right");
	
	ArenaLiveOptions:InitialiseButton(ALSpec_MatchStatisticLeaveArenaButton, addonName, nil, LeaveArenaButton_OnClick, L["STATISTIC_LEAVE_ARENA_BUTTON_TEXT"]);
end

function ALSpec_MatchStatistic:InitialiseTeamFrames(team)

	if ( not team ) then
		return;
	end
	
	local frame = _G["ALSpec_MatchStatistic"..team.."Team"];
	local prefix = frame:GetName();
	local teamName = ArenaLiveCore:GetDBEntry(addonName, "Teams/"..team.."/Name");
	
	frame.side = team;
	
	-- Initialise statistic handler:
	ArenaLiveCore:AddFrame(frame, "MatchStatistic");
	
	-- Get Team Colour:
	local red, green, blue = unpack(ArenaLiveSpectator.teamColours[team])
	
	-- Set child references:
	local child;
	for i = 1, 4 do
		if ( i == 4 ) then
			child = _G[prefix.."Header"];
			frame["header"] = child;
		else
			child = _G[prefix.."Player"..i];
			frame["player"..i] = child;
		end
			
		local childPrefix = child:GetName();
		
		child.background = _G[childPrefix.."Background"];
		child.icon = _G[childPrefix.."Icon"];
		child.name = _G[childPrefix.."NameText"];
		child.damage = _G[childPrefix.."DamageText"];
		child.highestDamage = _G[childPrefix.."HighestDamageText"];
		child.healing = _G[childPrefix.."HealingText"];
		child.killingBlows = _G[childPrefix.."KillingBlowsText"];
		child.timeCCd = _G[childPrefix.."TimeInCCText"];
		
	end
	
	-- Set Colour and texts of the Header:
	frame.header.background:SetVertexColor(red, green, blue, 1);
	frame.header.name:SetText(teamName);
	frame.header.damage:SetText(L["STATISTIC_HEADER_DAMAGE_TITLE"]);
	frame.header.highestDamage:SetText(L["STATISTIC_HEADER_HIGHEST_DAMAGE_TITLE"]);
	frame.header.healing:SetText(L["STATISTIC_HEADER_HEALING_TITLE"]);
	frame.header.killingBlows:SetText(L["STATISTIC_HEADER_KILLING_BLOWS_TITLE"]);
	frame.header.timeCCd:SetText(L["STATISTIC_HEADER_TIME_CCD_TITLE"]);
	
	-- Set OnShow Script:
	frame:SetScript("OnShow", TeamFrame_OnShow);
end

function ALSpec_MatchStatistic:OnMatchStart()
	ALSpec_MatchStatistic:StartTeamFrame(ALSpec_MatchStatisticLeftTeam);
	ALSpec_MatchStatistic:StartTeamFrame(ALSpec_MatchStatisticRightTeam);
	ALSpec_ScoreBoardShowStatisticBoardButton:Hide();
	self:Hide();
end

function ALSpec_MatchStatistic:OnMatchEnd()
	ALSpec_MatchStatisticLeftTeam:Stop();
	ALSpec_MatchStatisticRightTeam:Stop();
	ALSpec_ScoreBoardShowStatisticBoardButton:Show();
end

function ALSpec_MatchStatistic:StartTeamFrame(frame)

	local gameMode = ArenaLiveCore:GetDBEntry(addonName, "GameMode");

	-- Set Team Name already at the beginning of a match, as otherwise wrong data could be displayed:
	local teamName = ArenaLiveCore:GetDBEntry(addonName, "Teams/"..frame.side.."/Name");
	frame.header.name:SetText(teamName);
	
	-- Reset old Data:
	frame:Reset();
	
	-- Add new units:
	for i = 1, gameMode do
		local unitFrame = _G["ALSpec_"..frame.side.."Frame"..i];
		frame:AddUnit(unitFrame.unit);
	end
	
	frame:Start();
end